==> haskell-rio-prettyprint-0.1.6.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-prettyprint
version:              0.1.6.0
visibility:           public
id:                   rio-prettyprint-0.1.6.0-4SfZQnv6qcJ9AeI8oFJVAp
key:                  rio-prettyprint-0.1.6.0-4SfZQnv6qcJ9AeI8oFJVAp
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  2fa16fe5b90dffc78d213098895ddb69
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.0.2/site-local/rio-prettyprint-0.1.6.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/rio-prettyprint-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.6.0-4SfZQnv6qcJ9AeI8oFJVAp
depends:
    Cabal-3.4.1.0 aeson-2.1.2.1-5RDZhERJnAA4H89g4WTdzv
    annotated-wl-pprint-0.7.0-6vyiTB7Qv98BkD7hsY3Ewg
    ansi-terminal-0.11.4-941itkoMzqP2HjyJtSkjHb array-0.5.4.0
    base-4.15.1.0 colour-2.3.6-98es2b5kCfjL9kQ9aHpXxT mtl-2.2.2
    path-0.9.5-GlauGJqS4scKSwMAXfjNso
    rio-0.1.22.0-KwO7Ri2xoHX1wMTHmVkxDR text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-prettyprint-0.1.6.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-prettyprint
version:              0.1.6.0
visibility:           public
id:                   rio-prettyprint-0.1.6.0-LOGDhArxiIX1fH3eVbguJg
key:                  rio-prettyprint-0.1.6.0-LOGDhArxiIX1fH3eVbguJg
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  5a704e2f069ac45ca01512a459499d0f
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.0.2/site-local/rio-prettyprint-0.1.6.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/rio-prettyprint-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.6.0-LOGDhArxiIX1fH3eVbguJg
depends:
    Cabal-3.4.1.0 aeson-2.1.2.1-C2lvYQBBKZqBmgtqDyQIib
    annotated-wl-pprint-0.7.0-6vyiTB7Qv98BkD7hsY3Ewg
    ansi-terminal-0.11.4-941itkoMzqP2HjyJtSkjHb array-0.5.4.0
    base-4.15.1.0 colour-2.3.6-98es2b5kCfjL9kQ9aHpXxT mtl-2.2.2
    path-0.9.5-I2XAcviLLHqGB6JPqjBHgb
    rio-0.1.22.0-IZRnZ8wsJT6GYTK1WwvGYu text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
